"""Imagecast is like ImageMagick but for Pythonistas. Optionally provides its features via HTTP API."""
__appname__ = "imagecast"
__version__ = "0.4.0"
